==> smtk-v1.2.0.zip: smtk-v1.2.0/smtk/io/ResourceSetReader.h <==
//=========================================================================
//  Copyright (c) Kitware, Inc.
//  All rights reserved.
//  See LICENSE.txt for details.
//
//  This software is distributed WITHOUT ANY WARRANTY; without even
//  the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
//  PURPOSE.  See the above copyright notice for more information.
//=========================================================================
// .NAME ResourceSetReader.h - Reader for SMTK resource files
// .SECTION Description
// .SECTION See Also

#ifndef __smtk_io_ResourceSetReader_h
#define __smtk_io_ResourceSetReader_h

#include "smtk/CoreExports.h"
#include "smtk/PublicPointerDefs.h"
#include "smtk/SystemConfig.h"

#include "smtk/io/Logger.h"

#include "smtk/common/ResourceSet.h"

#include <iostream>
#include <string>

namespace pugi
{
class xml_node;
}

namespace smtk
{
namespace io
{

class SMTKCORE_EXPORT ResourceSetReader
{
  typedef std::map<std::string, smtk::common::ResourcePtr> ResourceMapType;

public:
  ResourceSetReader();
  ResourceSetReader(smtk::model::ManagerPtr mgr);

  bool readFile(std::string filename, smtk::common::ResourceSet& resources,
    smtk::io::Logger& logger, bool loadLinkedFiles = true);
  bool readString(const std::string& content, smtk::common::ResourceSet& resources,
    smtk::io::Logger& logger, bool loadLinkedFiles = true, ResourceMapType* resourceMap = NULL);

protected:
  bool readEmbeddedAttSystem(pugi::xml_node& element, smtk::common::ResourcePtr& resource,
    std::string& linkStartPath, smtk::io::Logger& logger);
  bool readIncludedManager(const pugi::xml_node& element, smtk::common::ResourcePtr& resource,
    std::string& path, smtk::io::Logger& logger);
  std::string buildIncludePath(
    const smtk::common::ResourceSet& resources, const std::string link) const;

  smtk::model::ManagerPtr m_modelManager;
};

} // namespace io
} // namespace smtk

#endif // __smtk_io_ResourceSetReader_h

==> smtk-v2.0.0.zip: smtk-v2.0.0/smtk/io/ResourceSetReader.h <==
//=========================================================================
//  Copyright (c) Kitware, Inc.
//  All rights reserved.
//  See LICENSE.txt for details.
//
//  This software is distributed WITHOUT ANY WARRANTY; without even
//  the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
//  PURPOSE.  See the above copyright notice for more information.
//=========================================================================
// .NAME ResourceSetReader.h - Reader for SMTK resource files
// .SECTION Description
// .SECTION See Also

#ifndef __smtk_io_ResourceSetReader_h
#define __smtk_io_ResourceSetReader_h

#include "smtk/CoreExports.h"
#include "smtk/PublicPointerDefs.h"
#include "smtk/SystemConfig.h"

#include "smtk/io/Logger.h"

#include "smtk/resource/Set.h"

#include <iostream>
#include <string>

namespace pugi
{
class xml_node;
}

namespace smtk
{
namespace io
{

class SMTKCORE_EXPORT ResourceSetReader
{
  typedef std::map<std::string, smtk::resource::ResourcePtr> ResourceMapType;

public:
  ResourceSetReader();
  ResourceSetReader(smtk::model::ManagerPtr mgr);

  bool readFile(std::string filename, smtk::resource::Set& resources, smtk::io::Logger& logger,
    bool loadLinkedFiles = true);
  bool readString(const std::string& content, smtk::resource::Set& resources,
    smtk::io::Logger& logger, bool loadLinkedFiles = true, ResourceMapType* resourceMap = NULL);

protected:
  bool readEmbeddedAttCollection(pugi::xml_node& element, smtk::resource::ResourcePtr& resource,
    std::string& linkStartPath, smtk::io::Logger& logger);
  bool readIncludedManager(const pugi::xml_node& element, smtk::resource::ResourcePtr& resource,
    std::string& path, smtk::io::Logger& logger);
  std::string buildIncludePath(const smtk::resource::Set& resources, const std::string link) const;

  smtk::model::ManagerPtr m_modelManager;
};

} // namespace io
} // namespace smtk

#endif // __smtk_io_ResourceSetReader_h
